@@ -228,7 +228,7 @@ func processBuildFlagTemplates(ctx *context.Context, docker config.Docker) ([]st
 }
 
 func dockerPush(ctx *context.Context, image *artifact.Artifact) error {
-	log.WithField("image", image.Name).Info("pushing docker image")
+	log.WithField("image", image.Name).Info("pushing")
 	docker := image.Extra[dockerConfigExtra].(config.Docker)
 	if err := imagers[docker.Use].Push(ctx, image.Name, docker.PushFlags); err != nil {
 		return err
