@@ -50,6 +50,14 @@ func GitTag(tb testing.TB, tag string) {
 	require.Empty(tb, out)
 }
 
+// GitAnnotatedTag creates an annotated tag.
+func GitAnnotatedTag(tb testing.TB, tag, message string) {
+	tb.Helper()
+	out, err := fakeGit("tag", "-a", tag, "-m", message)
+	require.NoError(tb, err)
+	require.Empty(tb, out)
+}
+
 // GitBranch creates a git branch.
 func GitBranch(tb testing.TB, branch string) {
 	tb.Helper()
